==> haskell-parallel-3.2.2.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parallel
version:              3.2.2.0
visibility:           public
id:                   parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
key:                  parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Parallel programming library
description:
    This package provides a library for parallel programming.

    For documentation start from the "Control.Parallel.Strategies"
    module below.

    For more tutorial documentation, see the book <http://simonmar.github.io/pages/pcph.html Parallel and Concurrent Programming in Haskell>.

    To understand the principles behind the library, see
    <http://simonmar.github.io/bib/papers/strategies.pdf Seq no more: Better Strategies for Parallel Haskell>.

category:             Control, Parallelism
abi:                  ae81e5b9d2ae987e85459583efc3455a
exposed:              True
exposed-modules:
    Control.Parallel Control.Parallel.Strategies Control.Seq

import-dirs:          /usr/lib/ghc-9.2.8/site-local/parallel-3.2.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/parallel-3.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parallel
hs-libraries:         HSparallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    ghc-prim-0.8.0

haddock-interfaces:   /usr/share/doc/haskell-parallel/html/parallel.haddock
haddock-html:         /usr/share/doc/haskell-parallel/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parallel-3.2.2.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parallel
version:              3.2.2.0
visibility:           public
id:                   parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
key:                  parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             Parallel programming library
description:
    This package provides a library for parallel programming.

    For documentation start from the "Control.Parallel.Strategies"
    module below.

    For more tutorial documentation, see the book <http://simonmar.github.io/pages/pcph.html Parallel and Concurrent Programming in Haskell>.

    To understand the principles behind the library, see
    <http://simonmar.github.io/bib/papers/strategies.pdf Seq no more: Better Strategies for Parallel Haskell>.

category:             Control, Parallelism
abi:                  6f2373b6f5218794ae4e80840f0f6895
exposed:              True
exposed-modules:
    Control.Parallel Control.Parallel.Strategies Control.Seq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/parallel-3.2.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parallel-3.2.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parallel-3.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parallel
hs-libraries:         HSparallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    ghc-prim-0.9.1

haddock-interfaces:   /usr/share/doc/haskell-parallel/html/parallel.haddock
haddock-html:         /usr/share/doc/haskell-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
